@@ -1,9 +1,12 @@
 import json
 import os
+import platform
+import socket
 import sys
 import time
 
 import requests
+from urllib3.connection import HTTPConnection
 
 from metasdk.__state import set_current_app
 from metasdk.event_bus import EventBus
@@ -76,8 +79,12 @@ class MetaApp(object):
                  meta_url: str = None,
                  api_proxy_url: str = None,
                  include_worker: bool = None,
-                 redis_url: str = None
+                 redis_url: str = None,
+                 setup_sockets: bool = True
                  ):
+        if setup_sockets:
+            self.setup_sockets()
+
         if debug is None:
             is_prod = os.environ.get('PRODUCTION', False)
             debug = os.environ.get('DEBUG', not is_prod)
@@ -89,7 +96,7 @@ class MetaApp(object):
 
         self.redis_url = os.environ.get("REDIS_URL", redis_url or "s1.meta.vmc.loc:6379:1")
         self.meta_url = os.environ.get("META_URL", meta_url or "http://apimeta.devision.io")
-        self.api_proxy_url = os.environ.get("API_PROXY_URL", api_proxy_url or "http://apiproxy.apis.devision.io")
+        self.api_proxy_url = os.environ.get("API_PROXY_URL", api_proxy_url or "https://apiproxy.apis.garpun.com")
 
         if debug and not starter_api_url:
             starter_api_url = DEV_STARTER_STUB_URL
@@ -106,7 +113,8 @@ class MetaApp(object):
         self.service_id = service_id
         self.dispatcher_name = self.service_ns + "." + self.service_id
 
-        create_logger(service_id=service_id, service_ns=service_ns, build_num=self.build_num, gcloud_log_host_port=gcloud_log_host_port, debug=self.debug)
+        create_logger(service_id=service_id, service_ns=service_ns, build_num=self.build_num,
+                      gcloud_log_host_port=gcloud_log_host_port, debug=self.debug)
 
         self.__read_developer_settings()
 
@@ -144,7 +152,8 @@ class MetaApp(object):
         :param part_log_time_minutes: Раз в какое кол-во минут пытаться писать лог
         :return: BulkLogger
         """
-        return BulkLogger(log=self.log, log_message=log_message, total=total, part_log_time_minutes=part_log_time_minutes)
+        return BulkLogger(log=self.log, log_message=log_message, total=total,
+                          part_log_time_minutes=part_log_time_minutes)
 
     def db(self, db_alias, shard_key=None):
         """
@@ -158,12 +167,14 @@ class MetaApp(object):
 
         db_key = db_alias + '__' + str(shard_key)
         if db_key not in self.__db_list:
-            self.__db_list[db_key] = DbQueryService(self, {"db_alias": db_alias, "dbAlias": db_alias, "shard_find_key": shard_key, "shardKey": shard_key})
+            self.__db_list[db_key] = DbQueryService(self, {"db_alias": db_alias, "dbAlias": db_alias,
+                                                           "shard_find_key": shard_key, "shardKey": shard_key})
         return self.__db_list[db_key]
 
     @property
     def user_agent(self):
-        return self.service_id + " | b" + self.build_num + (' | ' + self.user_agent_postfix if self.user_agent_postfix else "")
+        return self.service_id + " | b" + self.build_num + (
+            ' | ' + self.user_agent_postfix if self.user_agent_postfix else "")
 
     def __read_developer_settings(self):
         """
@@ -173,7 +184,8 @@ class MetaApp(object):
         """
         self.developer_settings = read_developer_settings()
         if not self.developer_settings:
-            self.log.warning("НЕ УСТАНОВЛЕНЫ настройки разработчика, это может приводить к проблемам в дальнейшей работе!")
+            self.log.warning(
+                "НЕ УСТАНОВЛЕНЫ настройки разработчика, это может приводить к проблемам в дальнейшей работе!")
 
     def api_call(self, service, method, data, options):
         """
@@ -232,7 +244,8 @@ class MetaApp(object):
 
         raise last_e
 
-    def native_api_call(self, service, method, data, options, multipart_form=False, multipart_form_data=None, stream=False, http_path="/api/meta/v1/", http_method='POST',
+    def native_api_call(self, service, method, data, options, multipart_form=False, multipart_form_data=None,
+                        stream=False, http_path="/api/meta/v1/", http_method='POST',
                         get_params=None, connect_timeout_sec=60, request_timeout_sec=1800):
         """
         :type app: metasdk.MetaApp
@@ -302,3 +315,29 @@ class MetaApp(object):
     def get_lib_version(self):
         from metasdk import info
         return info.__version__
+
+    @staticmethod
+    def setup_sockets():
+        """
+        Настройка для решения проблемы с разрывом соединения после, примерно, трёх минут при запросе к сервисам,
+        расположенным ва яндекс-облаке
+        (больше информации в задаче META-2932)
+        """
+
+        # Не все из этих параметров есть в каждой системе (в MacOS, например, нет socket.TCP_KEEPIDLE).
+        # Если сделать обычные списки, то при интерпретации отсутствующего параметра возникнет исключение.
+        # Чтобы этого избежать всё завёрнуто в лямбды
+        additional_socket_options_for_systems = {
+            "Windows": lambda: [(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1),
+                                (socket.IPPROTO_TCP, socket.TCP_KEEPIDLE, 10),
+                                (socket.IPPROTO_TCP, socket.TCP_KEEPINTVL, 60),
+                                (socket.IPPROTO_TCP, socket.TCP_KEEPCNT, 5)],
+            "Linux": lambda: [(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1),
+                              (socket.IPPROTO_TCP, socket.TCP_KEEPIDLE, 1),
+                              (socket.IPPROTO_TCP, socket.TCP_KEEPINTVL, 3),
+                              (socket.IPPROTO_TCP, socket.TCP_KEEPCNT, 5)],
+            "Darwin": lambda: [(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1),
+                               (socket.IPPROTO_TCP, 0x10, 3)]
+        }
+
+        HTTPConnection.default_socket_options += additional_socket_options_for_systems[platform.system()]()
